@@ -1,4 +1,4 @@
-.First.lib <- function(lib, pkg)  {
+.onAttach <- function(lib, pkg)  {
     packageStartupMessage("This is simba ",
                           utils::packageDescription("simba", field="Version"),
                           appendLF = TRUE)
